==> nextcloud-24.0.10.tgz: nextcloud/apps/survey_client/l10n/sr.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Последњи извештај послат: {on}",
    "An error occurred while sending your report." : "Грешка приликом слања извештаја.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Листа апликација <em>(за сваку апликацију: име, верзија и да ли је укључена)</em>",
    "Database environment <em>(type, version, database size)</em>" : "База <em>(тип, верзија, величина базе)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Информације о шифровању <em>(да ли је укључено?, који је подразумевани модул)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Број дељења <em>(по типу и типу дозвола)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP окружење <em>(верзија, лимити мемеорије, макс. време извршавања, макс. величина фајла)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Детаљи о инстанци сервера <em>(верзија, тип меморијског кеширања који се користи, стање закључавања, претпрегледа, аватара)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Статистике <em>(број: фајлова, корисника, складишта по типу, коментара, ознака)</em>",
    "Usage survey" : "Испитивање о коришћењу",
    "Help improve Nextcloud" : "Помозите нам побољшамо Некстклауд",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Да ли желите да нам помогнете да побољшамо Некстклауд тако што бисте нам послали анонимне податке о Вашим подешавањима и окружењу? Ово слање можете искључити сваког тренутка у административним поставкама.",
    "Not now" : "Не сад",
    "Send usage" : "Пошаљи коришћење",
    "Never" : "Никад",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Шаљите анонимизиране податке Некстклауду да нам помогнете да побољшамо Некстклауд.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Можете нам помоћи да побољшамо Некстклауд тако што ћете послати неке податке о Вашим тренутним подешавањима и употреби.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Ми узимамо Вашу приватност веома озбиљно. Слање података је подразумевано искључено и, уколико одаберете да га укључите, прво ће бити анонимизовано и биће Вам дата опција шта да поделите. По примању извештаја, претходни се уклања. Отпремите празан извештај да обришете све претходно сачуване податке на серверу",
    "Send new report now" : "Пошаљите извештај сада",
    "Send usage survey monthly" : "Пошаљите извештај о коришћењу на месечном нивоу",
    "Data to send" : "Подаци за слање",
    "Last report sent on: %s" : "Последњи извештај послат: %s",
    "Last report" : "Последњи извештај"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/survey_client/l10n/sr.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Последњи извештај послат: {on}",
    "An error occurred while sending your report." : "Грешка приликом слања извештаја.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Листа апликација <em>(за сваку апликацију: име, верзија и да ли је укључена)</em>",
    "Database environment <em>(type, version, database size)</em>" : "База <em>(тип, верзија, величина базе)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Информације о шифровању <em>(да ли је укључено?, који је подразумевани модул)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Број дељења <em>(по типу и типу дозвола)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP окружење <em>(верзија, лимити мемеорије, макс. време извршавања, макс. величина фајла)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Детаљи о инстанци сервера <em>(верзија, тип меморијског кеширања који се користи, стање закључавања, претпрегледа, аватара)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Статистике <em>(број: фајлова, корисника, складишта по типу, коментара, ознака)</em>",
    "Usage survey" : "Испитивање о коришћењу",
    "Help improve Nextcloud" : "Помозите нам побољшамо Некстклауд",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Да ли желите да нам помогнете да побољшамо Некстклауд тако што бисте нам послали анонимне податке о Вашим подешавањима и окружењу? Ово слање можете искључити сваког тренутка у административним поставкама.",
    "Send usage" : "Пошаљи коришћење",
    "Not now" : "Не сад",
    "Never" : "Никад",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Шаљите анонимизиране податке Некстклауду да нам помогнете да побољшамо Некстклауд.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Шаље анонимизиране податке компанији Nextcloud као помоћ у побољшању програма Nextcloud. Увек\n\t\tимате потпуну контролу садржаја који се шaље компанији Nextcloud и слање можете поново\n\t\tда искључите кад год то желите.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Можете нам помоћи да побољшамо Некстклауд тако што ћете послати неке податке о Вашим тренутним подешавањима и употреби.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. To delete the stored usage data, upload an empty report by unchecking all of the boxes then sending a new report." : "Ми узимамо вашу приватност веома озбиљно. Слање података је подразумевано искључено и, уколико одаберете да га укључите, прво ће бити анонимизовано и биће вам дата опција шта да поделите. По примању извештаја, претходни се уклања. Ако желите да обришете све претходно сачуване податке о коришћењу, отпремите празан извештај тако што одштилклирате све опције па пошаљете нови извештај.",
    "Send new report now" : "Пошаљите извештај сада",
    "Send usage survey monthly" : "Пошаљите извештај о коришћењу на месечном нивоу",
    "Data to send" : "Подаци за слање",
    "Last report sent on: %s" : "Последњи извештај послат: %s",
    "Last report" : "Последњи извештај"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
